@@ -14,12 +14,12 @@ try:
     from botocore.exceptions import ClientError
     from botocore.exceptions import NoCredentialsError
 except ImportError:
-    boto3 = None
+    boto3 = None  # type: ignore
 
 try:
     from mypy_boto3_secretsmanager.client import SecretsManagerClient
 except ImportError:
-    SecretsManagerClient = None
+    SecretsManagerClient = None  # type: ignore
 
 from secretbox.aws_loader import AWSLoader
 
